unit Unit1;

interface

uses
  Windows,
  Messages,
  SysUtils,
  Classes,
  Graphics,
  Controls,
  Forms,
  Dialogs,
  TMCDDrive,
  StdCtrls,
  ExtCtrls;

type
  TForm1 = class(TForm)
    Memo1: TMemo;
    Panel1: TPanel;
    RadioGroup1: TRadioGroup;
    CheckBox1: TCheckBox;
    Button1: TButton;
    Button2: TButton;
    CheckBox2: TCheckBox;
    Label1: TLabel;
    Label2: TLabel;
    Bevel1: TBevel;
    CheckBox3: TCheckBox;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure RadioGroup1Click(Sender: TObject);
    procedure TMCDDrive1CDEjected(Sender: TObject; DrivePath: string);
    procedure TMCDDrive1CDInserted(Sender: TObject; DrivePath: string);
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure CheckBox1Click(Sender: TObject);
    procedure CheckBox2Click(Sender: TObject);
    procedure Label1Click(Sender: TObject);
    procedure Label2Click(Sender: TObject);
    procedure CheckBox3Click(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    procedure ShowCDProperties(TMCDDrive1: TTMCDDrive; CDDrive: string = '');
  end;

var
  Form1: TForm1;

implementation

uses ShellApi;

{$R *.DFM}
var TMCDDrive1: TTMCDDrive;

function BoolToStr(Exp: Boolean): string;
begin
  if Exp then Result := 'True'
  else Result := 'False';
end;

procedure TForm1.FormCreate(Sender: TObject);
begin
  TMCDDrive1 := TTMCDDrive.Create(Self);
  RadioGroup1.Items.Assign(TMCDDrive1.CDDrives);
  RadioGroup1.ItemIndex := TMCDDrive1.CDDrives.IndexOf(TMCDDrive1.ActiveCD);
  TMCDDrive1.ActiveCDOnly := CheckBox1.Checked;
  TMCDDrive1.OnCDEjected := TMCDDrive1CDEjected;
  TMCDDrive1.OnCDInserted := TMCDDrive1CDInserted;
  CheckBox1.Checked := TMCDDrive1.ActiveCDOnly;
  CheckBox2.Checked := TMCDDrive1.Enabled;
  CheckBox3.Checked := TMCDDrive1.ShowStatusMsg;
  Memo1.Lines.Clear;
  ShowCDProperties(TMCDDrive1);
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  TMCDDrive1.Free;
end;

procedure TForm1.RadioGroup1Click(Sender: TObject);
begin
  TMCDDrive1.ActiveCD := RadioGroup1.Items[RadioGroup1.ItemIndex];
  ShowCDProperties(TMCDDrive1);
end;

procedure TForm1.ShowCDProperties(TMCDDrive1: TTMCDDrive; CDDrive: string = '');

begin
  if CDDrive = '' then CDDrive := TMCDDrive1.ActiveCD;
  with TMCDDrive1, Memo1.Lines do begin
    Add('');
    Add('ActiveCD      ' + ActiveCD);
    if CompareText(ActiveCD, CDDrive) <> 0
      then Add('Current CD    ' + CDDrive);
    Add('AudioCD       ' + BoolToStr(AudioCD));
    Add('Media Present ' + BoolToStr(CDMediaPresent[CDDrive]));
    Add('VolumeName    ' + CDVolumeName[CDDrive]);
    Add('SerialNumber  ' + CDSerialNumber[CDDrive]);
    Add('Identity      ' + CDIdentity[CDDrive]);
    Add('');
  end;
end;

procedure TForm1.TMCDDrive1CDEjected(Sender: TObject; DrivePath: string);
begin
  if TMCDDrive1.CDMediaPresent[DrivePath] then exit;
  with TMCDDrive1, Memo1.Lines do begin
    Add('   *******');
    Add('CD Ejected ' + DrivePath);
    Add('   *******');
  end;
  ShowCDProperties(TMCDDrive1, DrivePath);
end;

procedure TForm1.TMCDDrive1CDInserted(Sender: TObject; DrivePath: string);
begin
  with TMCDDrive1, Memo1.Lines do begin
    Add('   ********');
    Add('CD Inserted ' + DrivePath);
    Add('   ********');
  end;
  ShowCDProperties(TMCDDrive1, DrivePath);
end;

procedure TForm1.Button1Click(Sender: TObject);
begin
  TMCDDrive1.DoorOpen;
end;

procedure TForm1.Button2Click(Sender: TObject);
begin
  TMCDDrive1.DoorClose;
end;

procedure TForm1.CheckBox1Click(Sender: TObject);
begin
  TMCDDrive1.ActiveCDOnly := CheckBox1.Checked;
  with TMCDDrive1, Memo1.Lines do begin
    Add('   *******************');
    Add('TMCDDrive ActiveCDOnly = ' + BoolToStr(TMCDDrive1.ActiveCDOnly));
    Add('   *******************');
  end;
end;

procedure TForm1.CheckBox2Click(Sender: TObject);
begin
  TMCDDrive1.Enabled := CheckBox2.Checked;
  with TMCDDrive1, Memo1.Lines do begin
    Add('   **************');
    Add('TMCDDrive Enabled = ' + BoolToStr(TMCDDrive1.Enabled));
    Add('   **************');
  end;
end;

procedure TForm1.CheckBox3Click(Sender: TObject);
begin
  TMCDDrive1.ShowStatusMsg := CheckBox3.Checked;
  with TMCDDrive1, Memo1.Lines do begin
    Add('   **************');
    Add('TMCDDrive ShowStatusMsg = ' + BoolToStr(TMCDDrive1.ShowStatusMsg));
    Add('   **************');
  end;
  CheckBox3.Checked := TMCDDrive1.ShowStatusMsg;
end;

procedure TForm1.Label1Click(Sender: TObject);
begin
  ShellExecute(0, 'open',
    PChar('mailto:MilicT@yahoo.com'
    + '?subject=' + TMCDDrive1.ClassName +' component'
      + '&body=Hi Toma!%0d%0a'
      + 'Send me the TTMCDDrive component, but without nug screen, please!!%0d%0a'
      + 'I would like to use it!%0d%0a'
      + '%0d%0aRegards%0d%0aENTER YOUR COUNTRY, CITY AND (NICK)NAME PLEASE!' )
    , nil, nil, 1 {sw_Normal});
end;

procedure TForm1.Label2Click(Sender: TObject);
begin
  ShellExecute(0, 'open',
    PChar('http://www.geocities.com/MilicT/d5components.html')
    , nil, nil, 1 {sw_Normal});
end;

end.

